#!/usr/bin/python3
#
# Title:       Pattern for TID000019511
# Description: Using the find_multipaths yes option in multipath.conf
# Modified:    2021 Jun 18
#
##############################################################################
# Copyright (C) 2021 SUSE LLC
##############################################################################
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.
#
#  Authors/Contributors:
#   Jason Record <jason.record@suse.com>
#
##############################################################################

import re
import os
import Core

META_CLASS = "SLE"
META_CATEGORY = "MPIO"
META_COMPONENT = "Paths"
PATTERN_ID = os.path.basename(__file__)
PRIMARY_LINK = "META_LINK_TID"
OVERALL = Core.TEMP
OVERALL_INFO = "NOT SET"
OTHER_LINKS = "META_LINK_TID=https://www.suse.com/support/kb/doc/?id=000019511|META_LINK_BUG=https://bugzilla.suse.com/show_bug.cgi?id=1138452"
Core.init(META_CLASS, META_CATEGORY, META_COMPONENT, PATTERN_ID, PRIMARY_LINK, OVERALL, OVERALL_INFO, OTHER_LINKS)

##############################################################################
# Local Function Definitions
##############################################################################

def findMultipaths():
	fileOpen = "mpio.txt"
	section = "/multipath.conf"
	content = []
	CONFIRMED = re.compile(r"find_multipaths .*yes", re.IGNORECASE)
	if Core.isFileActive(fileOpen):
		if Core.getRegExSection(fileOpen, section, content):
			for line in content:
				if CONFIRMED.search(line):
					return True
	return False

def multipathsFound():
	fileOpen = "mpio.txt"
	section = "bin/multipath -ll"
	content = []
	if Core.getRegExSection(fileOpen, section, content):
		for line in content:
			if( line.startswith('`') ):
				return True
	return False

##############################################################################
# Main Program Execution
##############################################################################

if( findMultipaths() ):
	if( multipathsFound() ):
		Core.updateStatus(Core.WARN, "Detected find_multipaths setting, consider running multipath for new LUNs")
	else:
		Core.updateStatus(Core.IGNORE, "No multipath devices found")
else:
	Core.updateStatus(Core.ERROR, "ERROR: find_multipaths not configured")

Core.printPatternResults()

